.. _help:

Getting help
============

.. |email| image:: ../static/img/email.png

If you have any question, please join our `Slack workspace <https://join.slack.com/t/timeflux/shared_invite/enQtNjM1MDA1MTI1MTU1LWFjNGQxYmY0ZDgxMDI5MWU3ZDE2ZDMyYjBiNGNjMGZmNmNkNDAzNjM0NmE0MDY3ZWM3MGIzZTFiZjA5ZDNmYjM>`_. We will be glad to help.

You can also contact us by email: |email|.

We give workshops on a regular basis. These are great opportunities to interact in person. Subscribe to our `mailing-list <https://timeflux.io>`_ to be informed of future events.

Depending on your requirements, we may be able to offer commercial support, personalized training and custom development. Please get in touch!

.. tip:: If you don't know how to use a particular node, have a look at the API reference section. You will often find useful information there.

.. tip:: Most nodes have working examples you can get inspiration from. You just need to know where to look :) Example YAML files can usually be found in the `examples` directory of any of the GIT repositories (`Timeflux  <https://github.com/timeflux/timeflux/tree/master/examples>`_ or any plugin, for instance, the `DSP package <https://github.com/timeflux/timeflux_dsp/tree/master/examples>`_).